@@ -1,5 +1,5 @@
 from .exceptions import APIError
-#from .games import bedwars
+from .games import Bedwars
 from .profile import *
 
 
@@ -13,4 +13,5 @@ class Player:
 		self.data = data
 		self.name = self.data.get("player", {}).get("displayname")
 		self.uuid = self.data.get("player", {}).get("uuid")
-		self.rank = Rank(data)
\ No newline at end of file
+		self.rank = Rank(data)
+		self.bedwars = Bedwars(data)
\ No newline at end of file
